@@ -15,7 +15,7 @@ import tempfile
 import os
 import codecs
 
-__version__ = '0.3'
+__version__ = '0.4'
 
 def create_dir(path, tmpdir=u""):
     '''
@@ -268,6 +268,40 @@ def get_words(word_count=0, as_str=True):
     words = random.sample(_words, word_count)
     return words if not as_str else u' '.join(words)
 
+def get_email(name=u''):
+    '''return a random email address'''
+    if not name: name = get_ascii_name()
+
+    email_domains = [
+        u"yahoo.com",
+        u"hotmail.com",
+        u"outlook.com",
+        u"aol.com",
+        u"gmail.com",
+        u"msn.com",
+        u"comcast.net",
+        u"hotmail.co.uk",
+        u"sbcglobal.net",
+        u"yahoo.co.uk",
+        u"yahoo.co.in",
+        u"bellsouth.net",
+        u"verizon.com",
+        u"earthlink.net",
+        u"cox.net",
+        u"rediffmail.com",
+        u"yahoo.ca",
+        u"btinternet.com",
+        u"charter.net",
+        u"shaw.ca",
+        u"ntlworld.com",
+        u"gmx.com",
+        u"gmx.net",
+        u"mail.com",
+        u"mailinator.com"
+    ]
+
+    return u'{}@{}'.format(name, random.choice(email_domains))
+
 def get_name(name_count=2, as_str=True):
     '''
     get a random name
@@ -280,17 +314,38 @@ def get_name(name_count=2, as_str=True):
     return -- unicode|list -- your requested name
     '''
     # since we specified we didn't care, randomly choose how many surnames there should be
-    if name_count == 0:
+    if name_count <= 0:
         name_count = random.randint(1, 5)
 
     # decide if we should hyphenate the last name
-    if name_count > 1:
-        names = random.sample(_names, name_count)
-        if random.randint(0, 20) == 1:
-            names[-1] = u'{}-{}'.format(names[-1], random.choice(_names))
+    names = []
+    if name_count > 0:
+        #names = random.sample(_names, name_count)
+        for x in xrange(name_count):
+            if random.randint(0, 100) < 20:
+                names.append(get_unicode_name())
+            else:
+                names.append(get_ascii_name())
+
+        if name_count > 1:
+            if random.randint(0, 20) == 1:
+                names[-1] = u'{}-{}'.format(names[-1], random.choice(_names))
 
     return names if not as_str else u' '.join(names)
 
+def get_ascii_name():
+    '''return one ascii safe name'''
+    return random.choice(_names)
+
+def get_unicode_name():
+    '''
+    return one none ascii safe name
+
+    NOTE -- not all the names in _unicode_names are unicode, there are some ascii names in there
+    but I'm too lazy right now to go remove them
+    '''
+    return random.choice(_unicode_names)
+
 def get_coordinate(v1, v2, round_to=7):
     '''
     this will get a random coordinate between the values v1 and v2
@@ -582,80 +637,6 @@ Homer Simpson Marge Simpson Bart Simpson Lisa Simpson Maggie Simpson Ned Flander
 Rod Flanders Todd Flanders Itchy Scratchy Troy McClure Nelson Muntz Clancy Wiggum Ralph Wiggum Krusty
 Willie Blossom Bubbles Buttercup Abigail Bartlet
 
-\u0410\u0431\u0440\u0430\u043c Abram \u0410\u043b\u0435\u043a\u0441\u0430\u043d\u0434\u0440 Alexander
-\u0410\u043b\u0435\u043a\u0441\u0435\u0439 Alexei \u0410\u043b\u044c\u0431\u0435\u0440\u0442 Albert
-\u0410\u043d\u0430\u0442\u043e\u043b\u0438\u0439 Anatoly \u0410\u043d\u0434\u0440\u0435\u0439 Andrei
-\u0410\u043d\u0442\u043e\u043d Anton \u0410\u0440\u043a\u0430\u0434\u0438\u0439 Arkady \u0410\u0440\u0441\u0435\u043d\u0438\u0439
-Arseny \u0410\u0440\u0442\u0451\u043c Artyom \u0410\u0440\u0442\u0443\u0440 Artur \u0410\u0444\u0430\u043d\u0430\u0441\u0438\u0439
-Afanasy \u0411\u043e\u0433\u0434\u0430\u043d Bogdan \u0411\u043e\u0440\u0438\u0441 Boris \u0412\u0430\u0434\u0438\u043c
-Vadim \u0412\u0430\u043b\u0435\u043d\u0442\u0438\u043d Valentin \u0412\u0430\u043b\u0435\u0440\u0438\u0439 Valery
-\u0412\u0430\u0441\u0438\u043b\u0438\u0439 Vasily \u0412\u0435\u043d\u0438\u0430\u043c\u0438\u043d Veniamin
-\u0412\u0438\u043a\u0442\u043e\u0440 Viktor \u0412\u0438\u0442\u0430\u043b\u0438\u0439 Vitaly \u0412\u043b\u0430\u0434 Vlad
-\u0412\u043b\u0430\u0434\u0438\u043c\u0438\u0440 Vladimir \u0412\u043b\u0430\u0434\u0438\u0441\u043b\u0430\u0432 Vladislav
-\u0412\u0441\u0435\u0432\u043e\u043b\u043e\u0434 Vsevolod \u0412\u044f\u0447\u0435\u0441\u043b\u0430\u0432 Vyacheslav
-\u0413\u0430\u0432\u0440\u0438\u0438\u043b Gavriil \u0413\u0430\u0440\u0440\u0438 Garry
-\u0413\u0435\u043d\u043d\u0430\u0434\u0438\u0439 Gennady \u0413\u0435\u043e\u0440\u0433\u0438\u0439 Georgy
-\u0413\u0435\u0440\u0430\u0441\u0438\u043c Gerasim \u0413\u0435\u0440\u043c\u0430\u043d German \u0413\u043b\u0435\u0431
-Gleb \u0413\u0440\u0438\u0433\u043e\u0440\u0438\u0439 Grigory \u0414\u0430\u0432\u0438\u0434 David
-\u0414\u0430\u043d\u0438\u0438\u043b Daniil \u0414\u0435\u043d\u0438\u0441 Denis \u0414\u043c\u0438\u0442\u0440\u0438\u0439
-Dmitry \u0415\u0432\u0433\u0435\u043d\u0438\u0439 Evgeny \u0415\u0433\u043e\u0440 Yegor \u0415\u0444\u0438\u043c Yefim
-\u0417\u0430\u0445\u0430\u0440 Zakhar \u0418\u0432\u0430\u043d Ivan \u0418\u0433\u043d\u0430\u0442
-\u0418\u0433\u043d\u0430\u0442\u0438\u0439  eegNAHteey  Ignaty \u0418\u0433\u043e\u0440\u044c Igor
-\u0418\u043b\u043b\u0430\u0440\u0438\u043e\u043d Illarion \u0418\u043b\u044c\u044f Ilia
-\u0418\u043c\u043c\u0430\u043d\u0443\u0438\u043b Immanuil \u0418\u043e\u0441\u0438\u0444 Iosif
-\u041a\u0438\u0440\u0438\u043b\u043b Kirill \u041a\u043e\u043d\u0441\u0442\u0430\u043d\u0442\u0438\u043d Konstantin
-\u041b\u0435\u0432 Lev/Leo \u041b\u0435\u043e\u043d\u0438\u0434 Leonid \u041c\u0430\u043a\u0430\u0440 Makar
-\u041c\u0430\u043a\u0441\u0438\u043c Maxim \u041c\u0430\u0440\u0430\u0442 Marat \u041c\u0430\u0440\u043a Mark
-\u041c\u0430\u0442\u0432\u0435\u0439 Matvei \u041c\u0438\u0445\u0430\u0438\u043b Mikhail
-\u041d\u0435\u0441\u0442\u043e\u0440 Nestor \u041d\u0438\u043a\u0438\u0442\u0430 Nikita
-\u041d\u0438\u043a\u043e\u043b\u0430\u0439 Nikolay \u041e\u043b\u0435\u0433 Oleg \u041f\u0430\u0432\u0435\u043b
-Pavel \u041f\u0451\u0442\u0440 Pyotr/Peter \u0420\u043e\u0431\u0435\u0440\u0442 Robert
-\u0420\u043e\u0434\u0438\u043e\u043d Rodion \u0420\u043e\u043c\u0430\u043d Roman
-\u0420\u043e\u0441\u0442\u0438\u0441\u043b\u0430\u0432 Rostislav \u0420\u0443\u0441\u043b\u0430\u043d Ruslan
-\u0421\u0435\u043c\u0451\u043d Semyon \u0421\u0435\u0440\u0433\u0435\u0439 Sergei \u0421\u043f\u0430\u0440\u0442\u0430\u043a
-Spartak \u0421\u0442\u0430\u043d\u0438\u0441\u043b\u0430\u0432 Stanislav \u0421\u0442\u0435\u043f\u0430\u043d
-Stepan \u0422\u0430\u0440\u0430\u0441 Taras \u0422\u0438\u043c\u043e\u0444\u0435\u0439 Timofei
-\u0422\u0438\u043c\u0443\u0440 Timur \u0422\u0440\u043e\u0444\u0438\u043c Trofim \u042d\u0434\u0443\u0430\u0440\u0434
-Eduard \u042d\u0440\u0438\u043a Erik \u042e\u043b\u0438\u0430\u043d Yulian \u042e\u0440\u0438\u0439 Yury
-\u042f\u043a\u043e\u0432 Yakov \u042f\u0440\u043e\u0441\u043b\u0430\u0432 Yaroslav 
-\u0410\u043b\u0435\u043a\u0441\u0430\u043d\u0434\u0440\u0430 Alexandra \u0410\u043b\u0438\u043d\u0430
-Alina \u0410\u043b\u0438\u0441\u0430 Alisa \u0410\u043b\u043b\u0430 Alla \u0410\u043b\u0451\u043d\u0430
-Alyona \u0410\u043b\u044c\u0431\u0438\u043d\u0430 Albina \u0410\u043d\u0430\u0441\u0442\u0430\u0441\u0438\u044f
-Anastasiya \u0410\u043d\u043d\u0430 Anna \u0410\u043d\u0442\u043e\u043d\u0438\u043d\u0430 Antonina
-\u0410\u043d\u0436\u0435\u043b\u0438\u043a\u0430 Anzhelika \u0410\u043d\u0444\u0438\u0441\u0430 Anfisa
-\u0412\u0435\u0440\u0430 Vera \u0412\u0430\u043b\u0435\u0440\u0438\u044f Valeriya \u0412\u0430\u0440\u0432\u0430\u0440\u0430
-Varvara \u0412\u0430\u0441\u0438\u043b\u0438\u0441\u0430 Vasilisa \u0412\u043b\u0430\u0434\u043b\u0435\u043d\u0430
-Vladlena \u0412\u0435\u0440\u043e\u043d\u0438\u043a\u0430 Veronika \u0412\u0430\u043b\u0435\u043d\u0442\u0438\u043d\u0430
-Valentina \u0412\u0438\u043a\u0442\u043e\u0440\u0438\u044f Viktoriya \u0413\u0430\u043b\u0438\u043d\u0430
-Galina \u0414\u0430\u0440\u044c\u044f Darya \u0414\u0438\u043d\u0430 Dina \u0414\u0438\u0430\u043d\u0430
-Diana \u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430 Dominika \u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0430
-Ekateirna \u0415\u043b\u0435\u043d\u0430 Elena \u0415\u043b\u0438\u0437\u0430\u0432\u0435\u0442\u0430 Elizaveta
-\u0415\u0432\u0433\u0435\u043d\u0438\u044f Evgeniya \u0415\u0432\u0430 Eva \u0416\u0430\u043d\u043d\u0430 Zhanna
-\u0417\u0438\u043d\u0430\u0438\u0434\u0430 Zinaida \u0417\u043e\u044f Zoya \u0417\u043b\u0430\u0442\u0430 Zlata
-\u0418\u043d\u0433\u0430 Inga \u0418\u043d\u043d\u0430 Inna \u0418\u0440\u0438\u043d\u0430 Irina
-\u0418\u043d\u0435\u0441\u0441\u0430 Inessa \u0418\u0437\u0430\u0431\u0435\u043b\u043b\u0430 Izabella
-\u0418\u0437\u043e\u043b\u044c\u0434\u0430 Izolda \u0418\u0441\u043a\u0440\u0430 Iskra \u041a\u043b\u0430\u0440\u0430
-Klara \u041a\u043b\u0430\u0432\u0434\u0438\u044f Klavdiya \u041a\u0441\u0435\u043d\u0438\u044f Kseniya
-\u041a\u0430\u043f\u0438\u0442\u043e\u043b\u0438\u043d\u0430 Kapitolina \u041a\u043b\u0435\u043c\u0435\u043d\u0442\u0438\u043d\u0430
-Klementina \u041a\u0440\u0438\u0441\u0442\u0438\u043d\u0430 Kristina \u041b\u0430\u0434\u0430 Lada
-\u041b\u0430\u0440\u0438\u0441\u0430 Larisa \u041b\u0438\u0434\u0438\u044f Lidiya \u041b\u044e\u0431\u043e\u0432\u044c
-Lubov \u041b\u0438\u043b\u0438\u044f Liliya \u041b\u044e\u0434\u043c\u0438\u043b\u0430 Ludmila
-\u041b\u044e\u0441\u044f Lucya \u041c\u0430\u0440\u0433\u0430\u0440\u0438\u0442\u0430 Margarita
-\u041c\u0430\u0439\u044f Maya \u041c\u0430\u043b\u044c\u0432\u0438\u043d\u0430 Malvina \u041c\u0430\u0440\u0442\u0430
-Marta \u041c\u0430\u0440\u0438\u043d\u0430 Marina \u041c\u0430\u0440\u0438\u044f Mariya \u041d\u0430\u0434\u0435\u0436\u0434\u0430
-Nadezhda \u041d\u0430\u0442\u0430\u043b\u044c\u044f Natalya \u041d\u0435\u043b\u043b\u0438 Nelly \u041d\u0438\u043d\u0430
-Nina \u041d\u0438\u043a\u0430 Nika \u041d\u043e\u043d\u043d\u0430 Nonna \u041e\u043a\u0441\u0430\u043d\u0430 Oksana
-\u041e\u043b\u044c\u0433\u0430 Olga \u041e\u043b\u0435\u0441\u044f Olesya \u041f\u043e\u043b\u0438\u043d\u0430
-Polina \u0420\u0430\u0438\u0441\u0430 Raisa \u0420\u0430\u0434\u0430 Rada \u0420\u043e\u0437\u0430\u043b\u0438\u043d\u0430
-Rozalina \u0420\u0435\u0433\u0438\u043d\u0430 Regina \u0420\u0435\u043d\u0430\u0442\u0430 Renata
-\u0421\u0432\u0435\u0442\u043b\u0430\u043d\u0430 Svetlana \u0421\u043e\u0444\u044c\u044f \u0421\u043e\u0444\u0438\u044f
-Sofia \u0422\u0430\u0438\u0441\u0438\u044f Taisia \u0422\u0430\u043c\u0430\u0440\u0430 Tamara
-\u0422\u0430\u0442\u044c\u044f\u043d\u0430 Tatyana \u0423\u043b\u044c\u044f\u043d\u0430 Ulyana
-\u0424\u0430\u0438\u043d\u0430 Faina \u0424\u0435\u0434\u043e\u0441\u044c\u044f Fedosia
-\u0424\u043b\u043e\u0440\u0435\u043d\u0442\u0438\u043d\u0430 Florentina \u042d\u043b\u044c\u0432\u0438\u0440\u0430
-Elvira \u042d\u043c\u0438\u043b\u0438\u044f Emilia \u042d\u043c\u043c\u0430 Emma \u042e\u043b\u0438\u044f
-Yuliya \u042f\u0440\u043e\u0441\u043b\u0430\u0432\u0430 Yaroslava \u042f\u043d\u0430 Yana
-
 Abbie-Leigh Abbie-Louise Abbie-May Aimee-Grace Aimee-Jo Aimee-Lea Aimee-Lee Aimee-Leigh
 Aimee-Louise Aimee-Rose Alesha-Mae Alexa-Rose Alice-Mae Alice-May Alicia-Mae Alicia-May Alisha-May
 Alisha-Rose Alissa-Mae Alyssa-Mae Amber-Leigh Amber-Louise Amber-Mae Amber-Rose Amelia-Grace Amelia-Jane
@@ -761,10 +742,85 @@ L'Cole O'Jai O'Merion Q'ndell R'Son Sei'Jearr Ta'Quwereus Ted'Quarius Xa'Viance
 A'jA Anah'reya A'Majena Be'aJa Cier'rrea D'aSiyahna R'yaire D'Kota E'ryn I'Zeyonna Ja'genevia JaKeil'a Ta-Shay
 Ja'mya Jane't Kei'Lee Ken'yel K'le Mi'Angel N'finique Sanai' Sh'nia Syn'Cere Syri'yah Ti-Leigh'yah
 Zae'kee Zy'Erica Zy'rreah 
+""".strip())
+
+_unicode_names = re.split(r'\s+', u"""
+\u0410\u0431\u0440\u0430\u043c Abram \u0410\u043b\u0435\u043a\u0441\u0430\u043d\u0434\u0440 Alexander
+\u0410\u043b\u0435\u043a\u0441\u0435\u0439 Alexei \u0410\u043b\u044c\u0431\u0435\u0440\u0442 Albert
+\u0410\u043d\u0430\u0442\u043e\u043b\u0438\u0439 Anatoly \u0410\u043d\u0434\u0440\u0435\u0439 Andrei
+\u0410\u043d\u0442\u043e\u043d Anton \u0410\u0440\u043a\u0430\u0434\u0438\u0439 Arkady \u0410\u0440\u0441\u0435\u043d\u0438\u0439
+Arseny \u0410\u0440\u0442\u0451\u043c Artyom \u0410\u0440\u0442\u0443\u0440 Artur \u0410\u0444\u0430\u043d\u0430\u0441\u0438\u0439
+Afanasy \u0411\u043e\u0433\u0434\u0430\u043d Bogdan \u0411\u043e\u0440\u0438\u0441 Boris \u0412\u0430\u0434\u0438\u043c
+Vadim \u0412\u0430\u043b\u0435\u043d\u0442\u0438\u043d Valentin \u0412\u0430\u043b\u0435\u0440\u0438\u0439 Valery
+\u0412\u0430\u0441\u0438\u043b\u0438\u0439 Vasily \u0412\u0435\u043d\u0438\u0430\u043c\u0438\u043d Veniamin
+\u0412\u0438\u043a\u0442\u043e\u0440 Viktor \u0412\u0438\u0442\u0430\u043b\u0438\u0439 Vitaly \u0412\u043b\u0430\u0434 Vlad
+\u0412\u043b\u0430\u0434\u0438\u043c\u0438\u0440 Vladimir \u0412\u043b\u0430\u0434\u0438\u0441\u043b\u0430\u0432 Vladislav
+\u0412\u0441\u0435\u0432\u043e\u043b\u043e\u0434 Vsevolod \u0412\u044f\u0447\u0435\u0441\u043b\u0430\u0432 Vyacheslav
+\u0413\u0430\u0432\u0440\u0438\u0438\u043b Gavriil \u0413\u0430\u0440\u0440\u0438 Garry
+\u0413\u0435\u043d\u043d\u0430\u0434\u0438\u0439 Gennady \u0413\u0435\u043e\u0440\u0433\u0438\u0439 Georgy
+\u0413\u0435\u0440\u0430\u0441\u0438\u043c Gerasim \u0413\u0435\u0440\u043c\u0430\u043d German \u0413\u043b\u0435\u0431
+Gleb \u0413\u0440\u0438\u0433\u043e\u0440\u0438\u0439 Grigory \u0414\u0430\u0432\u0438\u0434 David
+\u0414\u0430\u043d\u0438\u0438\u043b Daniil \u0414\u0435\u043d\u0438\u0441 Denis \u0414\u043c\u0438\u0442\u0440\u0438\u0439
+Dmitry \u0415\u0432\u0433\u0435\u043d\u0438\u0439 Evgeny \u0415\u0433\u043e\u0440 Yegor \u0415\u0444\u0438\u043c Yefim
+\u0417\u0430\u0445\u0430\u0440 Zakhar \u0418\u0432\u0430\u043d Ivan \u0418\u0433\u043d\u0430\u0442
+\u0418\u0433\u043d\u0430\u0442\u0438\u0439  eegNAHteey  Ignaty \u0418\u0433\u043e\u0440\u044c Igor
+\u0418\u043b\u043b\u0430\u0440\u0438\u043e\u043d Illarion \u0418\u043b\u044c\u044f Ilia
+\u0418\u043c\u043c\u0430\u043d\u0443\u0438\u043b Immanuil \u0418\u043e\u0441\u0438\u0444 Iosif
+\u041a\u0438\u0440\u0438\u043b\u043b Kirill \u041a\u043e\u043d\u0441\u0442\u0430\u043d\u0442\u0438\u043d Konstantin
+\u041b\u0435\u0432 Lev/Leo \u041b\u0435\u043e\u043d\u0438\u0434 Leonid \u041c\u0430\u043a\u0430\u0440 Makar
+\u041c\u0430\u043a\u0441\u0438\u043c Maxim \u041c\u0430\u0440\u0430\u0442 Marat \u041c\u0430\u0440\u043a Mark
+\u041c\u0430\u0442\u0432\u0435\u0439 Matvei \u041c\u0438\u0445\u0430\u0438\u043b Mikhail
+\u041d\u0435\u0441\u0442\u043e\u0440 Nestor \u041d\u0438\u043a\u0438\u0442\u0430 Nikita
+\u041d\u0438\u043a\u043e\u043b\u0430\u0439 Nikolay \u041e\u043b\u0435\u0433 Oleg \u041f\u0430\u0432\u0435\u043b
+Pavel \u041f\u0451\u0442\u0440 Pyotr/Peter \u0420\u043e\u0431\u0435\u0440\u0442 Robert
+\u0420\u043e\u0434\u0438\u043e\u043d Rodion \u0420\u043e\u043c\u0430\u043d Roman
+\u0420\u043e\u0441\u0442\u0438\u0441\u043b\u0430\u0432 Rostislav \u0420\u0443\u0441\u043b\u0430\u043d Ruslan
+\u0421\u0435\u043c\u0451\u043d Semyon \u0421\u0435\u0440\u0433\u0435\u0439 Sergei \u0421\u043f\u0430\u0440\u0442\u0430\u043a
+Spartak \u0421\u0442\u0430\u043d\u0438\u0441\u043b\u0430\u0432 Stanislav \u0421\u0442\u0435\u043f\u0430\u043d
+Stepan \u0422\u0430\u0440\u0430\u0441 Taras \u0422\u0438\u043c\u043e\u0444\u0435\u0439 Timofei
+\u0422\u0438\u043c\u0443\u0440 Timur \u0422\u0440\u043e\u0444\u0438\u043c Trofim \u042d\u0434\u0443\u0430\u0440\u0434
+Eduard \u042d\u0440\u0438\u043a Erik \u042e\u043b\u0438\u0430\u043d Yulian \u042e\u0440\u0438\u0439 Yury
+\u042f\u043a\u043e\u0432 Yakov \u042f\u0440\u043e\u0441\u043b\u0430\u0432 Yaroslav 
+\u0410\u043b\u0435\u043a\u0441\u0430\u043d\u0434\u0440\u0430 Alexandra \u0410\u043b\u0438\u043d\u0430
+Alina \u0410\u043b\u0438\u0441\u0430 Alisa \u0410\u043b\u043b\u0430 Alla \u0410\u043b\u0451\u043d\u0430
+Alyona \u0410\u043b\u044c\u0431\u0438\u043d\u0430 Albina \u0410\u043d\u0430\u0441\u0442\u0430\u0441\u0438\u044f
+Anastasiya \u0410\u043d\u043d\u0430 Anna \u0410\u043d\u0442\u043e\u043d\u0438\u043d\u0430 Antonina
+\u0410\u043d\u0436\u0435\u043b\u0438\u043a\u0430 Anzhelika \u0410\u043d\u0444\u0438\u0441\u0430 Anfisa
+\u0412\u0435\u0440\u0430 Vera \u0412\u0430\u043b\u0435\u0440\u0438\u044f Valeriya \u0412\u0430\u0440\u0432\u0430\u0440\u0430
+Varvara \u0412\u0430\u0441\u0438\u043b\u0438\u0441\u0430 Vasilisa \u0412\u043b\u0430\u0434\u043b\u0435\u043d\u0430
+Vladlena \u0412\u0435\u0440\u043e\u043d\u0438\u043a\u0430 Veronika \u0412\u0430\u043b\u0435\u043d\u0442\u0438\u043d\u0430
+Valentina \u0412\u0438\u043a\u0442\u043e\u0440\u0438\u044f Viktoriya \u0413\u0430\u043b\u0438\u043d\u0430
+Galina \u0414\u0430\u0440\u044c\u044f Darya \u0414\u0438\u043d\u0430 Dina \u0414\u0438\u0430\u043d\u0430
+Diana \u0414\u043e\u043c\u0438\u043d\u0438\u043a\u0430 Dominika \u0415\u043a\u0430\u0442\u0435\u0440\u0438\u043d\u0430
+Ekateirna \u0415\u043b\u0435\u043d\u0430 Elena \u0415\u043b\u0438\u0437\u0430\u0432\u0435\u0442\u0430 Elizaveta
+\u0415\u0432\u0433\u0435\u043d\u0438\u044f Evgeniya \u0415\u0432\u0430 Eva \u0416\u0430\u043d\u043d\u0430 Zhanna
+\u0417\u0438\u043d\u0430\u0438\u0434\u0430 Zinaida \u0417\u043e\u044f Zoya \u0417\u043b\u0430\u0442\u0430 Zlata
+\u0418\u043d\u0433\u0430 Inga \u0418\u043d\u043d\u0430 Inna \u0418\u0440\u0438\u043d\u0430 Irina
+\u0418\u043d\u0435\u0441\u0441\u0430 Inessa \u0418\u0437\u0430\u0431\u0435\u043b\u043b\u0430 Izabella
+\u0418\u0437\u043e\u043b\u044c\u0434\u0430 Izolda \u0418\u0441\u043a\u0440\u0430 Iskra \u041a\u043b\u0430\u0440\u0430
+Klara \u041a\u043b\u0430\u0432\u0434\u0438\u044f Klavdiya \u041a\u0441\u0435\u043d\u0438\u044f Kseniya
+\u041a\u0430\u043f\u0438\u0442\u043e\u043b\u0438\u043d\u0430 Kapitolina \u041a\u043b\u0435\u043c\u0435\u043d\u0442\u0438\u043d\u0430
+Klementina \u041a\u0440\u0438\u0441\u0442\u0438\u043d\u0430 Kristina \u041b\u0430\u0434\u0430 Lada
+\u041b\u0430\u0440\u0438\u0441\u0430 Larisa \u041b\u0438\u0434\u0438\u044f Lidiya \u041b\u044e\u0431\u043e\u0432\u044c
+Lubov \u041b\u0438\u043b\u0438\u044f Liliya \u041b\u044e\u0434\u043c\u0438\u043b\u0430 Ludmila
+\u041b\u044e\u0441\u044f Lucya \u041c\u0430\u0440\u0433\u0430\u0440\u0438\u0442\u0430 Margarita
+\u041c\u0430\u0439\u044f Maya \u041c\u0430\u043b\u044c\u0432\u0438\u043d\u0430 Malvina \u041c\u0430\u0440\u0442\u0430
+Marta \u041c\u0430\u0440\u0438\u043d\u0430 Marina \u041c\u0430\u0440\u0438\u044f Mariya \u041d\u0430\u0434\u0435\u0436\u0434\u0430
+Nadezhda \u041d\u0430\u0442\u0430\u043b\u044c\u044f Natalya \u041d\u0435\u043b\u043b\u0438 Nelly \u041d\u0438\u043d\u0430
+Nina \u041d\u0438\u043a\u0430 Nika \u041d\u043e\u043d\u043d\u0430 Nonna \u041e\u043a\u0441\u0430\u043d\u0430 Oksana
+\u041e\u043b\u044c\u0433\u0430 Olga \u041e\u043b\u0435\u0441\u044f Olesya \u041f\u043e\u043b\u0438\u043d\u0430
+Polina \u0420\u0430\u0438\u0441\u0430 Raisa \u0420\u0430\u0434\u0430 Rada \u0420\u043e\u0437\u0430\u043b\u0438\u043d\u0430
+Rozalina \u0420\u0435\u0433\u0438\u043d\u0430 Regina \u0420\u0435\u043d\u0430\u0442\u0430 Renata
+\u0421\u0432\u0435\u0442\u043b\u0430\u043d\u0430 Svetlana \u0421\u043e\u0444\u044c\u044f \u0421\u043e\u0444\u0438\u044f
+Sofia \u0422\u0430\u0438\u0441\u0438\u044f Taisia \u0422\u0430\u043c\u0430\u0440\u0430 Tamara
+\u0422\u0430\u0442\u044c\u044f\u043d\u0430 Tatyana \u0423\u043b\u044c\u044f\u043d\u0430 Ulyana
+\u0424\u0430\u0438\u043d\u0430 Faina \u0424\u0435\u0434\u043e\u0441\u044c\u044f Fedosia
+\u0424\u043b\u043e\u0440\u0435\u043d\u0442\u0438\u043d\u0430 Florentina \u042d\u043b\u044c\u0432\u0438\u0440\u0430
+Elvira \u042d\u043c\u0438\u043b\u0438\u044f Emilia \u042d\u043c\u043c\u0430 Emma \u042e\u043b\u0438\u044f
+Yuliya \u042f\u0440\u043e\u0441\u043b\u0430\u0432\u0430 Yaroslava \u042f\u043d\u0430 Yana
 
 Rene\u2019e A\u2019Laysyn, D\u2019Kota \u2019Ese Cam\u2019Ron Da\u2019neyelle No\u2019elle ZI\u2019eyekel Miche\u2019le
-""")
-
+""".strip())
 # via: http://www.lipsum.com/feed/html
 # russian is from: http://masterrussian.com/vocabulary/most_common_words.htm
 # japanese (4bytes) are from: http://www.i18nguy.com/unicode/supplementary-test.html
@@ -875,7 +931,7 @@ if sys.maxunicode > 65535:
 \U00028cd2 \U00029d98
 '''
 
-_words = re.split(r'\s+', _paragraphs)
+_words = re.split(r'\s+', _paragraphs.strip())
 
 def _normpath(path):
     '''
